/******************************************************************************
 *
 * $Workfile: tpu.h $
 *
 * This module is the header file for tpu.s
 *
 * $History: tpu.h $
 *
 *****************************************************************************/
#ifndef INC_TPU_H
#define INC_TPU_H

#define TPU_GFUNCTIONS

/* Define a base interrupt for the TPU subsystem.
 */
#define TPU_INT 0x60


/* Define access to the parameter RAM for a channel
 */
#define PARAM_RAM_BASE (0xFFFF00)
#define PARAMETER_RAM( x ) ((volatile unsigned short *)(PARAM_RAM_BASE + (16 * x)))


/* Define equates for the channel priorities
 */
enum priorities {
   TPU_PRIORITY_NONE,
   TPU_PRIORITY_LOW,
   TPU_PRIORITY_MEDIUM,
   TPU_PRIORITY_HIGH
};


/* The following two enumeration declarations provide the numeric "channel
 * function select" codes for the A and G masks of the TPU. If you produce a
 * custom version of the TPU microcode, you will need to remove these two
 * enumerations and replace them with your own.
 */

#ifdef TPU_GFUNCTIONS
enum TPU_Gfunctions {
  TPU_FQD = 6,      /* Fast Quadrature Decode */
  TPU_MCPWM,        /* Multi-Channel Pulse Width Modulation */
  TPU_HALLD,        /* Hall-Effect Decode */
  TPU_COMM,         /* Motor Commutation */
  TPU_NITC,         /* New Input Transition Capture */
  TPU_UART,         /* Universal Asynchronous Receiver/Transmitter */
  TPU_FQM,          /* Frequency Measurement */
  TPU_TSM,          /* Table-Driven Stepper Motor Control */
  TPU_QOM,          /* Queued Output Match */
  TPU_PTA           /* Programmable Time Accumulator */
  };
#endif

#ifdef TPU_AFUNCTIONS
enum TPU_Afunctions {
  TPU_QDEC = 6,     /* Quadrature decode */
  TPU_SPWM,         /* Synchronized Pulse Width Modulation */
  TPU_DIO,          /* Discrete Input/Output */
  TPU_PWM,          /* Pulse Width Modulation */
  TPU_ITC,          /* Input Transition Capture */
  TPU_PMA,          /* Pulse Measurement/Accumulation */
  TPU_PSP,          /* Position-Synchronized Pulse Generation */
  TPU_SM,           /* Stepper Motor Control */
  TPU_OC,           /* Output Compare */
  TPU_PPWA          /* Period/Pulse Width Accumulation */
  };
#endif

/* Function prototypes.
 * These functions are defined in an assembly-language module.
 */

void  tpu_init(short TMCR_value, short vector, short level);
void  tpu_cfs_set(short channel, short function);
short tpu_cfs_get(short channel);
void  tpu_hsq_set(short channel, short value);
short tpu_hsq_get(short channel);
void  tpu_hsr_set(short channel, short value);
short tpu_hsr_get(short channel);
void  tpu_cpr_set(short channel, short priority);
short tpu_cpr_get(short channel);
void  tpu_int_enable(short channel);
void  tpu_int_disable(short channel);
short tpu_int_setting(short channel);
short tpu_int_status(short channel);
void  tpu_int_clear(short channel);
void  tpu_int_setup(short channel, void *function);
#endif

